===================================
Welcome to oslo.db's documentation!
===================================

The `oslo`_ db (database) handling library, it provides database connectivity
to different database backends and various other helper utils.

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing
   history

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _oslo: https://wiki.openstack.org/wiki/Oslo
